@@ -1,3 +1,7 @@
+
+#' @importFrom utils read.delim
+NA
+
 #' Read data files
 #' 
 #' A wrapper around various file reading functions.
@@ -23,13 +27,14 @@
 #' indicating the type of file being loaded.  The default is to use the filename
 #' to guess the type of file.
 #' 
+#' @param readr a logical indicating whether functions from the \code{readr} package should be
+#'   used, if available.
+#' 
 #' @param \dots  additional arguments passed on to 
 #'   \code{\link{read.table}}, or \code{\link{load}} or one of the functions
 #'   in the \code{readr} package.  Note that a message will indicate which 
 #'   underlying function is being used.
 #'   
-#' 
-#' 
 #' @details
 #' Unless \code{filetype} is specified,
 #' \code{read.file} uses the (case insensitive) file extension to determine how to read
@@ -39,12 +44,14 @@
 #' Otherwise, \code{\link{read.table}} is used.
 #' @param package if specified, files will be searched for among the documentation
 #' files provided by the package.
+#' @param stringsAsFactors a logical indicating whether strings should be converted to factors.
+#'   This has no affect when using \code{readr}.
 #' 
 #' @return A data frame, unless \code{file} unless \code{filetype} is \code{"rdata"}, 
 #' in which  case arbitrary objects may be loaded and a character vector
 #' holding the names of the loaded objects is returned invisibly.
-#' @seealso \code{\link[readr]{read_table}}, 
-#' \code{\link[readr]{read_csv}}, 
+#' @seealso \code{\link{read.csv}}, \code{\link{read.table}}, 
+#' \code{\link[readr]{read_table}}, \code{\link[readr]{read_csv}}, 
 #' \code{\link{load}}.
 #' 
 #' @keywords util 
@@ -57,11 +64,15 @@
 
 read.file <-
 function (file, header = T, na.strings = "NA",
-    comment.char = NULL, filetype = c("default", "csv", "txt", "tsv", "fw", "rdata"), 
+    comment.char = NULL, 
+    filetype = c("default", "csv", "txt", "tsv", "fw", "rdata"), 
+    stringsAsFactors = FALSE,
+    readr = FALSE,
     package=NULL, ...) 
 {
-  
+    readr_available <- readr && requireNamespace("readr")
     using_readr <- FALSE
+    
     if (!is.null(package)) {
       file <- docFile(file, package=package, character.only=TRUE)
     }
@@ -98,6 +109,8 @@ function (file, header = T, na.strings = "NA",
       using_readr <- FALSE
     }
     
+    using_readr <- using_readr && readr_available
+    
     if (using_readr) { 
       if (! is.null(comment.char)) message("comment.char is currently being ignored.")
       if (length(na.strings) > 1) {
@@ -113,18 +126,23 @@ function (file, header = T, na.strings = "NA",
       } else {
         message("Reading data with read.csv()")
         return(read.csv(file, header=header, na.strings = na.strings, 
-                        stringsAsFactors = FALSE, ...))
+                        stringsAsFactors = stringsAsFactors, ...))
       }
     }
     
-    if (filetype == "fw") {
+    if (filetype == "fw" && readr_available) {
       message("Reading data with readr::read_table()")
       return(as.data.frame(readr::read_table(file, col_names = header, na = na.strings, ...)))
     }
     
     if (filetype == "tsv") {
-      message("Reading data with readr::read_tsv()")
-      return(as.data.frame(readr::read_tsv(file, col_names = header, na = na.strings, ...)))
+      if (using_readr) {
+        message("Reading data with readr::read_tsv()")
+        return(as.data.frame(readr::read_tsv(file, col_names = header, na = na.strings, ...)))
+      } else {
+        message("Reading data with read.delim()")
+        return(read.delim(file, header = header, na = na.strings, ...))
+      }
     }
     
     if (filetype == "rdata") {
@@ -136,6 +154,6 @@ function (file, header = T, na.strings = "NA",
     # fall through to read.table() for any other file format.
     message("Reading data with read.table()")
     return(
-      read.table(file, header = header, na.strings = na.strings, stringsAsFactors=FALSE,...)
+      read.table(file, header = header, na.strings = na.strings, stringsAsFactors=stringsAsFactors,...)
     )
 }
